/****************************************************************************
** Meta object code from reading C++ file 'qtractorTempoAdjustForm.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../qtractor/src/qtractorTempoAdjustForm.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'qtractorTempoAdjustForm.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN23qtractorTempoAdjustFormE_t {};
} // unnamed namespace

template <> constexpr inline auto qtractorTempoAdjustForm::qt_create_metaobjectdata<qt_meta_tag_ZN23qtractorTempoAdjustFormE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "qtractorTempoAdjustForm",
        "tempoChanged",
        "",
        "tempoDetect",
        "tempoReset",
        "tempoAdjust",
        "tempoTap",
        "rangeStartChanged",
        "rangeLengthChanged",
        "rangeBeatsChanged",
        "formatChanged",
        "changed",
        "accept",
        "reject"
    };

    QtMocHelpers::UintData qt_methods {
        // Slot 'tempoChanged'
        QtMocHelpers::SlotData<void()>(1, 2, QMC::AccessProtected, QMetaType::Void),
        // Slot 'tempoDetect'
        QtMocHelpers::SlotData<void()>(3, 2, QMC::AccessProtected, QMetaType::Void),
        // Slot 'tempoReset'
        QtMocHelpers::SlotData<void()>(4, 2, QMC::AccessProtected, QMetaType::Void),
        // Slot 'tempoAdjust'
        QtMocHelpers::SlotData<void()>(5, 2, QMC::AccessProtected, QMetaType::Void),
        // Slot 'tempoTap'
        QtMocHelpers::SlotData<void()>(6, 2, QMC::AccessProtected, QMetaType::Void),
        // Slot 'rangeStartChanged'
        QtMocHelpers::SlotData<void(unsigned long)>(7, 2, QMC::AccessProtected, QMetaType::Void, {{
            { QMetaType::ULong, 2 },
        }}),
        // Slot 'rangeLengthChanged'
        QtMocHelpers::SlotData<void(unsigned long)>(8, 2, QMC::AccessProtected, QMetaType::Void, {{
            { QMetaType::ULong, 2 },
        }}),
        // Slot 'rangeBeatsChanged'
        QtMocHelpers::SlotData<void(int)>(9, 2, QMC::AccessProtected, QMetaType::Void, {{
            { QMetaType::Int, 2 },
        }}),
        // Slot 'formatChanged'
        QtMocHelpers::SlotData<void(int)>(10, 2, QMC::AccessProtected, QMetaType::Void, {{
            { QMetaType::Int, 2 },
        }}),
        // Slot 'changed'
        QtMocHelpers::SlotData<void()>(11, 2, QMC::AccessProtected, QMetaType::Void),
        // Slot 'accept'
        QtMocHelpers::SlotData<void()>(12, 2, QMC::AccessProtected, QMetaType::Void),
        // Slot 'reject'
        QtMocHelpers::SlotData<void()>(13, 2, QMC::AccessProtected, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<qtractorTempoAdjustForm, qt_meta_tag_ZN23qtractorTempoAdjustFormE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject qtractorTempoAdjustForm::staticMetaObject = { {
    QMetaObject::SuperData::link<QDialog::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN23qtractorTempoAdjustFormE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN23qtractorTempoAdjustFormE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN23qtractorTempoAdjustFormE_t>.metaTypes,
    nullptr
} };

void qtractorTempoAdjustForm::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<qtractorTempoAdjustForm *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->tempoChanged(); break;
        case 1: _t->tempoDetect(); break;
        case 2: _t->tempoReset(); break;
        case 3: _t->tempoAdjust(); break;
        case 4: _t->tempoTap(); break;
        case 5: _t->rangeStartChanged((*reinterpret_cast<std::add_pointer_t<ulong>>(_a[1]))); break;
        case 6: _t->rangeLengthChanged((*reinterpret_cast<std::add_pointer_t<ulong>>(_a[1]))); break;
        case 7: _t->rangeBeatsChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 8: _t->formatChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 9: _t->changed(); break;
        case 10: _t->accept(); break;
        case 11: _t->reject(); break;
        default: ;
        }
    }
}

const QMetaObject *qtractorTempoAdjustForm::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *qtractorTempoAdjustForm::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN23qtractorTempoAdjustFormE_t>.strings))
        return static_cast<void*>(this);
    return QDialog::qt_metacast(_clname);
}

int qtractorTempoAdjustForm::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QDialog::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 12)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 12;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 12)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 12;
    }
    return _id;
}
QT_WARNING_POP
